@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2001  The Exult Team
+ *  Copyright (C) 2000-2013  The Exult Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,50 +16,49 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef	_ARGS_H_
-#define	_ARGS_H_
+#ifndef _ARGS_H_
+#define _ARGS_H_
 
 // Handy argument processor. I'm certain the implementation could be better
 // but it suffices quite well at the moment.
 
-#include "exult_types.h"
+#include "common_types.h"
 
 #ifdef __DECCXX
 #  undef declare
 #endif
 
-#ifndef ALPHA_LINUX_CXX
-#  include <string>
-#endif
+#include <string>
 #include <vector>
 
-class	Args
-{
-	struct Opts
-	{
-		std::string	option;
-		bool	*bval;
-		std::string  *sval;
-		int	*ival;
-		uint32 *uval;
-
-		bool	dbval;
-		std::string	dsval;
-		int	dival;
-		uint32 duval;
-		enum { no_type=0,type_bool,type_string,type_int,type_unsigned } valuetype;
-		Opts() :option(""),valuetype(no_type) {};
-		~Opts() {};
+class   Args {
+	struct Opts {
+		std::string option;
+		union {
+			bool    *bval;
+			std::string  *sval;
+			int *ival;
+			uint32 *uval;
+		};
+		union {
+			bool    dbval;
+			const char *dsval;
+			int dival;
+			uint32 duval;
+		};
+		enum { no_type = 0, type_bool, type_string, type_int, type_unsigned } valuetype;
+		Opts() : option(""), sval(0), dsval(0), valuetype(no_type) {}
+		~Opts() {}
 	};
 	std::vector<Opts> options;
-	public:
-	Args() {};
-	~Args() {};
-	void	declare(const char *s,bool *b,bool defval=true);
-	void	declare(const char *s,std::string *b,const char *defval=0);
-	void	declare(const char *s,int *b,int defval=0);
-	void	declare(const char *s,uint32 *b,uint32 defval=0);
-	void	process(int argc,char **argv);
+public:
+	Args() {}
+	~Args() {}
+	void    declare(const char *s, bool *b, bool defval = true);
+	void    declare(const char *s, std::string *b, const char *defval = 0);
+	void    declare(const char *s, int *b, int defval = 0);
+	void    declare(const char *s, uint32 *b, uint32 defval = 0);
+	void    process(int argc, char **argv);
 };
 
 #endif
