@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2001  The Exult Team
+ *  Copyright (C) 2000-2013  The Exult Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #ifndef CONV_H
 #define CONV_H
 
-extern int bgconv[];
+extern const int bgconv[];
+extern const int bgconvsong[];
 
 #endif
