@@ -135,10 +135,10 @@ void SoundTester::test_sound()
 			delete scroll;
 			redraw = false;
 		}
-			SDL_WaitEvent(&event);
+		SDL_WaitEvent(&event);
 		if(event.type==SDL_KEYDOWN)
 		{
-       			redraw = true;
+			redraw = true;
 			switch(event.key.keysym.sym)
 			{
 
@@ -147,10 +147,11 @@ void SoundTester::test_sound()
 				break;
 
 			case SDLK_RETURN:
+			case SDLK_KP_ENTER:
 				if (active == 0)
 				{
 					audio->stop_music();
-					audio->start_music (song, repeat, 0);
+					audio->start_music (song, repeat);
 				}
 				else if (active == 1)
 				{
