@@ -1,8 +1,8 @@
 /*
- *	dir.h - Directions.
+ *  dir.h - Directions.
  *
  *  Copyright (C) 1998-1999  Jeffrey S. Freedman
- *  Copyright (C) 2000-2001  The Exult Team
+ *  Copyright (C) 2000-2013  The Exult Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,38 +20,38 @@
  */
 
 #ifndef DIR_H
-#define DIR_H	1
+#define DIR_H   1
 
 /*
- *	Directions:
+ *  Directions:
  */
-enum Direction
-	{
-	north = 0,
-	northeast = 1,
-	east = 2,
-	southeast = 3,
-	south = 4,
-	southwest = 5,
-	west = 6,
-	northwest = 7
-	};
+enum Direction {
+    north = 0,
+    northeast = 1,
+    east = 2,
+    southeast = 3,
+    south = 4,
+    southwest = 5,
+    west = 6,
+    northwest = 7
+};
 
-Direction Get_direction
-	(
-	int deltay,
-	int deltax
-	);
-Direction Get_direction4
-	(
-	int deltay,
-	int deltax
-	);
+Direction Get_direction_NoWrap(
+    int deltay,
+    int deltax
+);
+Direction Get_direction(
+    int deltay,
+    int deltax
+);
+Direction Get_direction4(
+    int deltay,
+    int deltax
+);
 
-int Get_direction16
-	(
-	int deltay,
-	int deltax
-	);
+int Get_direction16(
+    int deltay,
+    int deltax
+);
 
 #endif
