@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2001  The Exult Team
+ *  Copyright (C) 2001-2013 The Exult Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,20 +25,33 @@
 class Mouse;
 class Image_buffer8;
 class Game_window;
+class BaseGameInfo;
+class ModManager;
+class MenuList;
+class Shape_frame;
 
 class ExultMenu {
 private:
+	Font *font;
+	Font *fonton;
+	Font *navfont;
+	Font *navfonton;
 	Game_window *gwin;
 	Image_buffer8 *ibuf;
 	Vga_file exult_flx;
-	//	Palette pal;
-	int topx, topy, centerx, centery, menuy;
+	//  Palette pal;
+	int centerx, centery;
+	int pagesize;
 	void calc_win();
 	Mouse *menu_mouse;
+	MenuList *create_main_menu(Shape_frame *bg, int first = 0);
+	MenuList *create_mods_menu(ModManager *selgame, Shape_frame *bg, int first = 0);
+	BaseGameInfo *show_mods_menu(ModManager *selgame, Shape_frame *bg);
+
 public:
 	ExultMenu(Game_window *gw);
 	~ExultMenu();
-	Exult_Game run();
+	BaseGameInfo *run();
 	void setup();
 };
 
