@@ -27,28 +27,24 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 
 /*
- *	Create book display.
+ *  Create book display.
  */
 
-Book_gump::Book_gump
-	(
-	bool serp
-	) : Text_gump(game->get_shape("gumps/book"), serp)
-{
+Book_gump::Book_gump(
+    int fnt, int gump
+) : Text_gump(gump < 0 ? game->get_shape("gumps/book") : gump, fnt) {
 }
 
 /*
- *	Paint book.  Updates curend.
+ *  Paint book.  Updates curend.
  */
 
-void Book_gump::paint
-	(
-	)
-{
-					// Paint the gump itself.
+void Book_gump::paint(
+) {
+	// Paint the gump itself.
 	paint_shape(x, y);
-					// Paint left page.
+	// Paint left page.
 	curend = paint_page(Rectangle(36, 10, 122, 130), curtop);
-					// Paint right page.
+	// Paint right page.
 	curend = paint_page(Rectangle(174, 10, 122, 130), curend);
 }
