@@ -22,34 +22,32 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "Gump.h"
 #include "misc_buttons.h"
 #include "Face_button.h"
+#include "ignore_unused_variable_warning.h"
 
 class Actor;
 
 /*
- *	A rectangular area showing party combat statistics:
+ *  A rectangular area showing party combat statistics:
  */
-class CombatStats_gump : public Gump
-{
-	UNREPLICATABLE_CLASS(CombatStats_gump);
+class CombatStats_gump : public Gump {
+	UNREPLICATABLE_CLASS_I(CombatStats_gump, Gump())
 
 public:
 	CombatStats_gump(int initx, int inity);
-	~CombatStats_gump();
-					// Add object.
+	virtual ~CombatStats_gump();
+	// Add object.
 	virtual int add(Game_object *obj, int mx = -1, int my = -1,
-			int sx = -1, int sy = -1, bool dont_check = false,
-						bool combine = false)
-		{ return 0; }		// Can't drop onto it.
-					// Paint it and its contents.
+	                int sx = -1, int sy = -1, bool dont_check = false,
+	                bool combine = false) {
+		ignore_unused_variable_warning(obj, mx, my, sx, sy, dont_check, combine);
+		return 0;    // Can't drop onto it.
+	}
+	// Paint it and its contents.
 	virtual void paint();
-	virtual Gump_button *on_button(int mx, int my);
 
 private:
-	Actor* party[9];
+	Actor *party[9];
 	int party_size;
-	Halo_button* halo_btn[9];
-	Combat_mode_button* cmb_btn[9];
-	Face_button* face_btn[9];
 };
 
 #endif
