@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2001 The Exult Team
+Copyright (C) 2001-2013 The Exult Team
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -23,11 +23,41 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "Enabled_button.h"
 #include "gamewin.h"
 
-const char* Enabled_button::selections[] = { "Disabled", "Enabled" };
+const char *Enabled_button::selections[] = { "Disabled", "Enabled" };
 
+/*
+ *  Redisplay as 'pushed'.
+ */
+
+bool Enabled_button::push(
+    int button
+) {
+	if (button == 1 || button == 3) {
+		set_pushed(button);
+		paint();
+		gwin->set_painted();
+		return true;
+	}
+	return false;
+}
+
+/*
+ *  Redisplay as 'unpushed'.
+ */
+
+void Enabled_button::unpush(
+    int button
+) {
+	if (button == 1 || button == 3) {
+		set_pushed(false);
+		paint();
+		gwin->set_painted();
+	}
+}
+
+bool Enabled_button::activate(int button) {
+	if (button != 1 && button != 3) return false;
 
-void Enabled_button::activate()
-{
 	set_frame(get_framenum() + 1);
 	if (get_framenum() >= 2) set_frame(0);
 	text = selections[get_framenum()];
@@ -35,4 +65,6 @@ void Enabled_button::activate()
 	toggle(get_framenum());
 	paint();
 	gwin->set_painted();
+
+	return true;
 }
