@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2001 The Exult Team
+Copyright (C) 2001-2013 The Exult Team
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -23,31 +23,33 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 class Gump_button;
 
-class Gamemenu_gump : public Modal_gump
-{
-	UNREPLICATABLE_CLASS_I(Gamemenu_gump,Modal_gump(0,0,0,0));
+class Gamemenu_gump : public Modal_gump {
+	UNREPLICATABLE_CLASS_I(Gamemenu_gump, Modal_gump(0, 0, 0, 0))
 
- private:
-	Gump_button* buttons[6];
+private:
+	Gump_button *buttons[6];
 
- public:
+public:
 	Gamemenu_gump();
-	~Gamemenu_gump();
+	virtual ~Gamemenu_gump();
 
-					// Paint it and its contents.
+	// Paint it and its contents.
 	virtual void paint();
-	virtual void close()
-		{ done = 1; }
-					// Handle events:
-	virtual void mouse_down(int mx, int my);
-	virtual void mouse_up(int mx, int my);
+	virtual void close() {
+		done = 1;
+	}
+	// Handle events:
+	virtual bool mouse_down(int mx, int my, int button);
+	virtual bool mouse_up(int mx, int my, int button);
 
 	void quit(bool return_to_menu = false);
 	void loadsave();
 	void video_options();
 	void audio_options();
 	void gameplay_options();
-	void combat_options();
+	void misc_options();
+
+	static void do_exult_menu();
 };
 
 #endif
