@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2001 The Exult Team
+Copyright (C) 2001-2013 The Exult Team
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -24,13 +24,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 class Gump_button;
 
-class GameplayOptions_gump : public Modal_gump
-{
-	UNREPLICATABLE_CLASS_I(GameplayOptions_gump,Modal_gump(0,0,0,0));
-
- private:
-	Gump_button* buttons[14];
+class GameplayOptions_gump : public Modal_gump {
+	UNREPLICATABLE_CLASS_I(GameplayOptions_gump, Modal_gump(0, 0, 0, 0))
 
+private:
 	int facestats;
 	int fastmouse;
 	int mouse3rd;
@@ -40,25 +37,46 @@ class GameplayOptions_gump : public Modal_gump
 	int paperdolls;
 	int text_bg;
 	int frames;
-	int	doubleright_move;
-	int	gumps_pause;
+	int right_pathfind;
+	int gumps_pause;
 
-	std::string* frametext;
+	std::string *frametext;
 	int num_framerates;
+	int smooth_scrolling;
 
- public:
+	enum button_ids {
+	    id_first = 0,
+	    id_ok = id_first,
+	    id_cancel,
+	    id_facestats,
+	    id_text_bg,
+	    id_fastmouse,
+	    id_mouse3rd,
+	    id_doubleclick,
+	    id_rightclick_close,
+	    id_right_pathfind,
+	    id_gumps_pause,
+	    id_cheats,
+	    id_frames,
+	    id_smooth_scrolling,
+	    id_paperdolls,
+	    id_count
+	};
+	Gump_button *buttons[id_count];
+
+public:
 	GameplayOptions_gump();
-	~GameplayOptions_gump();
+	virtual ~GameplayOptions_gump();
 
-					// Paint it and its contents.
+	// Paint it and its contents.
 	virtual void paint();
 	virtual void close();
 
- 					// Handle events:
-	virtual void mouse_down(int mx, int my);
-	virtual void mouse_up(int mx, int my);
+	// Handle events:
+	virtual bool mouse_down(int mx, int my, int button);
+	virtual bool mouse_up(int mx, int my, int button);
 
-	void toggle(Gump_button* btn, int state);
+	void toggle(Gump_button *btn, int state);
 	void build_buttons();
 
 	void load_settings();
