@@ -23,65 +23,65 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "gamewin.h"
 #include "Gump_button.h"
 #include "Gump.h"
-
+#include "ignore_unused_variable_warning.h"
 
 /*
- *	Redisplay as 'pushed'.
+ *  Redisplay as 'pushed'.
  */
 
-void Gump_button::push
-	(
-	)
-{
-	pushed = 1;
-	paint();
-	gwin->set_painted();
+bool Gump_button::push(
+    int button
+) {
+	if (button == 1) {
+		set_pushed(button);
+		paint();
+		gwin->set_painted();
+		return true;
+	}
+	return false;
 }
 
 /*
- *	Redisplay as 'unpushed'.
+ *  Redisplay as 'unpushed'.
  */
 
-void Gump_button::unpush
-	(
-	)
-{
-	pushed = 0;
-	paint();
-	gwin->set_painted();
+void Gump_button::unpush(
+    int button
+) {
+	if (button == 1) {
+		set_pushed(false);
+		paint();
+		gwin->set_painted();
+	}
 }
 
 /*
- *	Default method for double-click.
+ *  Default method for double-click.
  */
 
-void Gump_button::double_clicked
-	(
-	int x, int y
-	)
-{
+void Gump_button::double_clicked(
+    int x, int y
+) {
+	ignore_unused_variable_warning(x, y);
 }
 
 /*
- *	Repaint checkmark, etc.
+ *  Repaint checkmark, etc.
  */
 
-void Gump_button::paint
-	(
-	)
-{
+void Gump_button::paint(
+) {
 	int px = 0;
 	int py = 0;
 
-	if (parent)
-	{
+	if (parent) {
 		px = parent->get_x();
 		py = parent->get_y();
 	}
 
 	int prev_frame = get_framenum();
-	set_frame(prev_frame + pushed);
-	paint_shape(x+px, y+py);
+	set_frame(prev_frame + (is_pushed() ? 1 : 0));
+	paint_shape(x + px, y + py);
 	set_frame(prev_frame);
 
 }
