@@ -23,21 +23,21 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "gump_types.h"
 #include "shapeid.h"
 #include "rect.h"
+#include "ignore_unused_variable_warning.h"
 
 class Gump;
 class Game_window;
 
 /*
- *	A gump widget, such as a button or text field:
+ *  A gump widget, such as a button or text field:
  */
-class Gump_widget : public ShapeID
-{
-	UNREPLICATABLE_CLASS(Gump_widget);
+class Gump_widget : public ShapeID {
+	UNREPLICATABLE_CLASS_I(Gump_widget, ShapeID())
 
 protected:
 	Gump_widget() : parent(0) {  }
-	Gump *parent;		// Who this is in.
-	short x, y;			// Coords. relative to parent.
+	Gump *parent;       // Who this is in.
+	short x, y;         // Coords. relative to parent.
 
 public:
 	friend class Gump;
@@ -45,17 +45,27 @@ public:
 	friend class Spellscroll_gump;
 	Gump_widget(Gump *par, int shnum, int px, int py, ShapeFile shfile = SF_GUMPS_VGA)
 		: ShapeID(shnum, 0, shfile), parent(par), x(px), y(py)
-		{  }
-					// Is a given point on the widget?
-	virtual int on_widget(int mx, int my);
-
+	{  }
+	virtual Gump_widget *clone(Gump *par) {
+		ignore_unused_variable_warning(par);
+		return 0;
+	}
+	virtual ~Gump_widget() {  }
+	// Is a given point on the widget?
+	virtual int on_widget(int mx, int my) const;
+	virtual int on_button(int mx, int my) const {
+		ignore_unused_variable_warning(mx, my);
+		return 0;
+	}
 	virtual void paint();
 
 	virtual Rectangle get_rect();
-					// update the widget, if required
+	// update the widget, if required
 	virtual void update_widget() { }
 
-	virtual bool is_draggable() { return true; }
+	virtual bool is_draggable() {
+		return true;
+	}
 
 };
 
