@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2001 The Exult Team
+Copyright (C) 2001-2013 The Exult Team
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -27,23 +27,23 @@ class Game_window;
 class Jawbone_object;
 
 class Jawbone_gump : public Gump {
- public:
+public:
 	Jawbone_gump(Jawbone_object *cont, int initx, int inity);
 
-	~Jawbone_gump() {}
+	virtual ~Jawbone_gump() {}
 
 	// Find the object the mouse is over
 	virtual Game_object *find_object(int mx, int my);
 
 	// Add object.
-	virtual int add(Game_object *obj, int mx = -1, int my = -1, 
-			int sx = -1, int sy = -1, bool dont_check = false,
-						bool combine = false);
+	virtual int add(Game_object *obj, int mx = -1, int my = -1,
+	                int sx = -1, int sy = -1, bool dont_check = false,
+	                bool combine = false);
 
 	// Paint it and its contents.
 	virtual void paint();
 
- private:
+private:
 	void set_to_spot(Game_object *obj, int sx, int sy);
 	void paint_tooth(int index);
 
