@@ -24,76 +24,79 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 class Spellbook_object;
 class Bookmark_button;
 
+template <typename T>
+int sign(T val) {
+	return (T(0) < val) - (val < T(0));
+}
+
 /*
- *	Abstract base class for spellbook, spell-scrolls:
+ *  Abstract base class for spellbook, spell-scrolls:
  */
-class Spelltype_gump : public Gump
-	{
+class Spelltype_gump : public Gump {
 public:
 	Spelltype_gump(int shnum) : Gump(0, shnum) {  }
 	virtual ~Spelltype_gump() {  }
-					// Perform spell.
+	// Perform spell.
 	virtual void do_spell(int spell) = 0;
-					// Set bookmark.
+	// Set bookmark.
 	virtual void select_spell(int spell) = 0;
-	};
+};
 
 /*
- *	Open spellbook.  The spells are drawn in the object area.
+ *  Open spellbook.  The spells are drawn in the object area.
  */
-class Spellbook_gump : public Spelltype_gump
-	{
-	int page;			// Starting with 0 (= circle #).
-	int turning_page;		// 1 if turning forward, -1 backward,
-					//   0 if not turning.
-	int turning_frame;		// Next frame to show.
-	short avail[9*8];		// For each spell, # which the
-					//   available reagents make possible.
-	Spellbook_object *book;		// Book this shows.
-	Game_object *book_owner;	// Top-owner of book.
-					// Page turners:
+class Spellbook_gump : public Spelltype_gump {
+	int page;           // Starting with 0 (= circle #).
+	int turning_page;       // 1 if turning forward, -1 backward,
+	//   0 if not turning.
+	int turning_frame;      // Next frame to show.
+	short avail[9 * 8];     // For each spell, # which the
+	//   available reagents make possible.
+	Spellbook_object *book;     // Book this shows.
+	Game_object *book_owner;    // Top-owner of book.
+	// Page turners:
 	Gump_button *leftpage, *rightpage;
 	Bookmark_button *bookmark;
-	Gump_button *spells[9*8];	// ->spell 'buttons'.
-	int spwidth, spheight;		// Dimensions of a spell shape.
-	void set_avail();		// Set up counts.
+	Gump_button *spells[9 * 8]; // ->spell 'buttons'.
+	int spwidth, spheight;      // Dimensions of a spell shape.
+	void set_avail();       // Set up counts.
 public:
 	friend class Bookmark_button;
 	Spellbook_gump(Spellbook_object *b);
-	~Spellbook_gump();
-	virtual void do_spell(int spell);	// Perform spell.
-	void change_page(int delta);	// Page forward/backward.
-	virtual void select_spell(int spell);	// Set bookmark.
+	virtual ~Spellbook_gump();
+	virtual void do_spell(int spell);   // Perform spell.
+	void change_page(int delta);    // Page forward/backward.
+	virtual void select_spell(int spell);   // Set bookmark.
 	virtual Game_object *get_owner();// Get object this belongs to.
-					// Is a given point on a button?
+	// Is a given point on a button?
 	virtual Gump_button *on_button(int mx, int my);
-					// Paint button.
+	// Paint button.
 	virtual void paint_button(Gump_button *btn);
-					// Paint it and its contents.
+	// Paint it and its contents.
 	virtual void paint();
-	};
+	virtual bool handle_kbd_event(void *ev);
+};
 
 /*
- *	Open spell-scroll in Serpent Isle.
+ *  Open spell-scroll in Serpent Isle.
  */
-class Spellscroll_gump : public Spelltype_gump
-	{
-	Game_object *scroll;		// Scroll clicked on.
+class Spellscroll_gump : public Spelltype_gump {
+	Game_object *scroll;        // Scroll clicked on.
 	Gump_button *spell;
-	int spwidth, spheight;		// Dimensions of a spell shape.
+	int spwidth, spheight;      // Dimensions of a spell shape.
 public:
 	Spellscroll_gump(Game_object *s);
-	~Spellscroll_gump();
-	virtual void do_spell(int spell);	// Perform spell.
+	virtual ~Spellscroll_gump();
+	virtual void do_spell(int spell);   // Perform spell.
 	virtual void select_spell(int)
-		{  }
+	{  }
 	virtual Game_object *get_owner();// Get object this belongs to.
-					// Is a given point on a button?
+	// Is a given point on a button?
 	virtual Gump_button *on_button(int mx, int my);
-					// Paint button.
+	// Paint button.
 	virtual void paint_button(Gump_button *btn);
-					// Paint it and its contents.
+	// Paint it and its contents.
 	virtual void paint();
-	};
+};
 
 #endif
