@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2001 The Exult Team
+Copyright (C) 2001-2013 The Exult Team
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,26 +22,27 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "Gump_button.h"
 #include <string>
 
-class Text_button : public Gump_button
-{
+class Text_button : public Gump_button {
 protected:
-	std::string	text;
-	int		text_x;
-	int		text_y;
-	int		width;
-	int		height;
+	std::string text;
+	int     text_x;
+	int     text_y;
+	int     width;
+	int     height;
 
 	void init();
 
 public:
 	Text_button(Gump *p, const std::string &str, int x, int y, int w = 0, int h = 0);
+	virtual ~Text_button() {  }
 	virtual void paint();
 
-	virtual int on_widget(int mx, int my);
+	virtual int on_widget(int mx, int my) const;
+
+	virtual int on_button(int mx, int my) const {
+		return on_widget(mx, my);
+	}
 
-	virtual int on_button(int mx, int my)
-	{ return on_widget (mx, my); }
-	
 };
 
 #endif
