@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2000 The Exult Team
+Copyright (C) 2000-2013 The Exult Team
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,112 +20,96 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #  include <config.h>
 #endif
 
-#ifndef ALPHA_LINUX_CXX
-#  include <cstring>
-#endif
+#include <cstring>
 
 #include "gamewin.h"
 #include "Text_gump.h"
 
-#ifndef UNDER_CE
 using std::strchr;
 using std::strcpy;
 using std::strlen;
-#endif
 
 /*
- *	Add to the text, starting a newline.
+ *  Add to the text, starting a newline.
  */
 
-void Text_gump::add_text
-	(
-	const char *str
-	)
-{
-	int slen = strlen(str);		// Length of new text.
-					// Allocate new space.
+void Text_gump::add_text(
+    const char *str
+) {
+	int slen = strlen(str);     // Length of new text.
+	// Allocate new space.
 	char *newtext = new char[textlen + (textlen != 0) + slen + 1];
-	if (textlen)			// Copy over old.
-		{
+	if (textlen) {          // Copy over old.
 		strcpy(newtext, text);
 		// Add new line if not starting a new page and if first char of new string is
 		// not a new line
-		if (newtext[textlen-1] != '*') newtext[textlen++] = '~';
-		}
-	strcpy(newtext + textlen, str);	// Append new.
+		if (newtext[textlen - 1] != '*') newtext[textlen++] = '~';
+	}
+	strcpy(newtext + textlen, str); // Append new.
 	delete [] text;
 	text = newtext;
 	textlen += slen;
 }
 
 /*
- *	Paint a page and find where its text ends.
+ *  Paint a page and find where its text ends.
  *
- *	Output:	Index past end of displayed page.
+ *  Output: Index past end of displayed page.
  */
 
-int Text_gump::paint_page
-	(
-	Rectangle box,			// Display box rel. to gump.
-	int start			// Starting offset into text.
-	)
-{
-	const int font = serpentine?8:4;	// Black.
-	const int vlead = 1;		// Extra inter-line spacing.
+int Text_gump::paint_page(
+    Rectangle const &box,           // Display box rel. to gump.
+    int start           // Starting offset into text.
+) {
+	const int vlead = 1;        // Extra inter-line spacing.
 	int ypos = 0;
 	int textheight = sman->get_text_height(font) + vlead;
 	char *str = text + start;
-	while (*str && *str != '*' && ypos + textheight <= box.h)
-	{
-		if (*str == '~')	// Empty paragraph?
-		{
+	while (*str && *str != '*' && ypos + textheight <= box.h) {
+		if (*str == '~') {  // Empty paragraph?
 			ypos += textheight;
 			str++;
 			continue;
 		}
-					// Look for page break.
+		// Look for page break.
 		char *epage = strchr(str, '*');
-					// Look for line break.
+		// Look for line break.
 		char *eol = strchr(str, '~');
 		if (epage && (!eol || eol > epage))
 			eol = epage;
-		if (!eol)		// No end found?
+		if (!eol)       // No end found?
 			eol = text + textlen;
-		char eolchr = *eol;	// Save char. at EOL.
+		char eolchr = *eol; // Save char. at EOL.
 		*eol = 0;
 		int endoff = sman->paint_text_box(font, str, x + box.x,
-				y + box.y + ypos, box.w, box.h - ypos, vlead);
-		*eol = eolchr;		// Restore char.
-		if (endoff > 0)		// All painted?
-		{		// Value returned is height.
+		                                  y + box.y + ypos, box.w, box.h - ypos, vlead);
+		*eol = eolchr;      // Restore char.
+		if (endoff > 0) {   // All painted?
+			// Value returned is height.
 			str = eol + (eolchr == '~');
 			ypos += endoff;
-		}
-		else			// Out of room.
-		{
+		} else {        // Out of room.
 			str += -endoff;
 			break;
 		}
 	}
-	if (*str == '*')		// Saw end of page?
+	if (*str == '*')        // Saw end of page?
 		str++;
-	gwin->set_painted();		// Force blit.
-	return (str - text);		// Return offset past end.
+	gwin->set_painted();        // Force blit.
+	return (str - text);        // Return offset past end.
 }
 
 /*
- *	Show next page(s) of book or scroll.
+ *  Show next page(s) of book or scroll.
  *
- *	Output:	0 if already at end.
+ *  Output: 0 if already at end.
  */
 
-int Text_gump::show_next_page
-	(
-	)
-{
+int Text_gump::show_next_page(
+) {
 	if (curend >= textlen)
-		return (0);		// That's all, folks.
-	curtop = curend;		// Start next page or pair of pages.
-	paint();			// Paint.  This updates curend.
+		return (0);     // That's all, folks.
+	curtop = curend;        // Start next page or pair of pages.
+	paint();            // Paint.  This updates curend.
 	return (1);
 }
