@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2000 The Exult Team
+Copyright (C) 2000-2013 The Exult Team
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,28 +22,28 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "Gump.h"
 
 /*
- *	A text gump is the base class for books and scrolls.
+ *  A text gump is the base class for books and scrolls.
  */
-class Text_gump : public Gump
-{
-	UNREPLICATABLE_CLASS(Text_gump);
+class Text_gump : public Gump {
+	UNREPLICATABLE_CLASS_I(Text_gump, Gump())
 
 protected:
-	char *text;			// The text.
-	int textlen;			// Length of text.
-	int curtop;			// Offset of top of current page.
-	int curend;			// Offset past end of current page(s).
-	bool serpentine;		// Serpentine text. SI ONLY!
+	char *text;         // The text.
+	int textlen;            // Length of text.
+	int curtop;         // Offset of top of current page.
+	int curend;         // Offset past end of current page(s).
+	int font;       // The shape in fonts.vga to use
 
 public:
-	Text_gump(int shapenum, bool serp = false) : Gump(0, shapenum),
-				text(0), textlen(0), curtop(0), curend(0), serpentine(serp)
-		{  }
-	~Text_gump()
-		{ delete [] text; }
-	void add_text(const char *str);	// Append text.
-	int paint_page(Rectangle box, int start);
-					// Next page of book/scroll.
+	Text_gump(int shapenum, int fnt = 4) : Gump(0, shapenum),
+		text(0), textlen(0), curtop(0), curend(0), font(fnt)
+	{  }
+	virtual ~Text_gump() {
+		delete [] text;
+	}
+	void add_text(const char *str); // Append text.
+	int paint_page(Rectangle const &box, int start);
+	// Next page of book/scroll.
 	int show_next_page();
 };
 
