@@ -20,53 +20,50 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #ifndef INCL_GAMMA
-#define INCL_GAMMA	1
+#define INCL_GAMMA  1
 
-#ifndef ALPHA_LINUX_CXX
-#  include <cmath>
-#endif
+#include <cmath>
 
-#ifndef UNDER_CE
 using std::pow;
-#endif
 
-template <class T> class GammaTable
-{
+template <class T> class GammaTable {
 private:
-	unsigned	size;
-	float		sizef;
-	T			*table;
-	float		gamma;
+	unsigned    size;
+	float       sizef;
+	T           *table;
+	float       gamma;
 
 	// No
 	GammaTable() { }
 
 public:
 
-	inline const float & get_gamma ()
-	{	return gamma; }
+	inline const float &get_gamma() {
+		return gamma;
+	}
 
-	inline void set_gamma (float g)
-	{
+	inline void set_gamma(float g) {
 		if (g < 0.001f) g = 0.001f;
-		if (g == gamma) return;	
+		if (g == gamma) return;
 		gamma = g;
 
 		for (unsigned i = 0; i < size; i++)
-			table[i] = (T) (pow (i / sizef, 1 / gamma) * sizef);
+			table[i] = static_cast<T>(pow(i / sizef, 1 / gamma) * sizef);
 	}
 
-	GammaTable (unsigned int s, float g = 1) : sizef(-1), gamma(-1)
-	{
-		sizef += size = s>2?s:2;	
+	GammaTable(unsigned int s, float g = 1) : sizef(-1), gamma(-1) {
+		sizef += size = s > 2 ? s : 2;
 		table = new T [size];
 		set_gamma(g);
 	}
 
-	~GammaTable () { delete [] table; }
+	~GammaTable() {
+		delete [] table;
+	}
 
-	inline const T & operator [] (const T &i) const
-	{	return table[i]; }
+	inline const T &operator [](const T &i) const {
+		return table[i];
+	}
 
 };
 
