@@ -14,23 +14,33 @@
 #define HAVE_SSTREAM 1
 
 // Firstly some things that need to be defined
-#define VERSION "1.2"
+#define VERSION "1.6.0"
 #define EXULT_DATADIR "data/"
 #define SIZEOF_SHORT 2
 #define SIZEOF_INT 4
 #define SIZEOF_LONG 4
+#define SIZEOF_INTP 4
 #define DONT_HAVE_HASH_SET
 #define DONT_HAVE_HASH_MAP
 //#define HAVE_OPENGL
 //#define FUDGE_SAMPLE_RATES
 #define USE_FMOPL_MIDI
+#define USE_MT32EMU_MIDI
+#define USE_TIMIDITY_MIDI
+#define HAVE_OPENGL
+//#define HAVE_FREETYPE2
+
+#define _CRT_SECURE_NO_WARNINGS
+#define _CRT_NONSTDC_NO_WARNINGS
 
 #ifndef WIN32
 #error WTF!
 #endif
 
 // No GDI
+#ifndef ALLOW_GDI
 #define NOGDI
+#endif
 
 // Settings for debug builds
 #ifndef NDEBUG
@@ -46,6 +56,8 @@
 
 #endif
 
+#define NOMINMAX
+
 // Yeah, lets do unicode compiles
 //#define UNICODE
 
@@ -53,8 +65,8 @@
 #define WIN32_LEAN_AND_MEAN
 
 // Disable some warnings
-#pragma warning (disable: 4786)	// Debug Len > 255
-#pragma warning (disable: 4355)	// 'this' : used in base member initializer list
+#pragma warning (disable: 4786) // Debug Len > 255
+#pragma warning (disable: 4355) // 'this' : used in base member initializer list
 
 #ifndef ENABLE_EXTRA_WARNINGS
 //#pragma warning (disable: 4101) // unreferenced local variable
@@ -83,35 +95,35 @@ namespace std {
 
 extern "C" {
 
-	#include <wchar.h>
-	#include <sys/types.h>
+#include <wchar.h>
+#include <sys/types.h>
 	//#include <sys/stat.h>
-	#include <errno.h>
-	#include <ctype.h>
-	#include <signal.h>
-	#include <cstdlib>
-	#include <cstring>
-	#include <ctime>
-	#include <cmath>
-	#include <cstdarg>
-	#include <malloc.h>
+#include <errno.h>
+#include <ctype.h>
+#include <signal.h>
+#include <cstdlib>
+#include <cstring>
+#include <ctime>
+#include <cmath>
+#include <cstdarg>
+#include <malloc.h>
 
 };
-	// Kludge to make Exult think that size_t has been put into the
-	// std namespace
-	typedef ::size_t size_t2;
-	#define size_t size_t2
+// Kludge to make Exult think that size_t has been put into the
+// std namespace
+typedef ::size_t size_t2;
+#define size_t size_t2
 
-	// These are declared/defined in <cstdio> and the need to be in 
-	// the std namespace
-	using ::FILE;
-	using ::fread;
-	using ::va_list;
-	using ::fopen;
-	using ::fclose;
-	using ::fwrite;
-	using ::remove;
-	using ::printf;
+// These are declared/defined in <cstdio> and the need to be in
+// the std namespace
+using ::FILE;
+using ::fread;
+using ::va_list;
+using ::fopen;
+using ::fclose;
+using ::fwrite;
+using ::remove;
+using ::printf;
 }
 
 // These get put in std when they otherwise should be, or are required by other headers
@@ -139,7 +151,7 @@ using std::strtol;
 //
 // Hacks for MSVC 7
 //
-#elif (_MSC_VER == 1300)
+#elif (_MSC_VER == 1300 || _MSC_VER == 1400)
 
 #include <cctype>
 #define HAVE_SYS_STAT_H
@@ -200,6 +212,10 @@ using std::getline;
 #endif
 
 // Only include these headers if we are actually compiling Exult
+#ifndef EXULT
+#define EXULT
+#endif
+
 #ifdef EXULT
 
 #ifndef HAVE_ZIP_SUPPORT
@@ -212,7 +228,7 @@ using std::getline;
 #include "../actions.h"
 #include "../actors.h"
 #include "../args.h"
-#include "../bggame.h"
+#include "../gamemgr/bggame.h"
 #include "../browser.h"
 #include "../cheat.h"
 #include "../cheat_screen.h"
@@ -224,7 +240,6 @@ using std::getline;
 #include "../headers/common_types.h"
 #include "../exult.h"
 #include "../exult_constants.h"
-#include "../exult_types.h"
 #include "../exultmenu.h"
 #include "../fnames.h"
 #include "../frameseq.h"
@@ -235,23 +250,19 @@ using std::getline;
 #include "../hash_utils.h"
 #include "../keyactions.h"
 #include "../keys.h"
-#include "../lists.h"
 #include "../menulist.h"
 #include "../mouse.h"
 #include "../npcnear.h"
 #include "../npctime.h"
 #include "../palette.h"
 #include "../paths.h"
-#include "../ready.h"
 #include "../rect.h"
 #include "../schedule.h"
-#include "../segfile.h"
 #include "../shapeid.h"
-#include "../sigame.h"
+#include "../gamemgr/sigame.h"
 #include "../tiles.h"
 #include "../tqueue.h"
 #include "../txtscroll.h"
-#include "../vec.h"
 #include "../flic/playfli.h"
 #include "../pathfinder/Astar.h"
 #include "../pathfinder/PathFinder.h"
@@ -281,11 +292,6 @@ using std::getline;
 #include "../usecode/ucsched.h"
 #include "../usecode/ucscriptop.h"
 #include "../usecode/useval.h"
-#include "../audio/Audio.h"
-#include "../audio/conv.h"
-#include "../audio/Midi.h"
-#include "../audio/soundtest.h"
-#include "../audio/xmidi.h"
 #include "../gumps/Actor_gump.h"
 #include "../gumps/AudioOptions_gump.h"
 #include "../gumps/Book_gump.h"
@@ -319,12 +325,10 @@ using std::getline;
 #include "../imagewin/imagebuf.h"
 #include "../imagewin/imagewin.h"
 #include "../imagewin/iwin8.h"
-#include "../shapes/bodies.h"
+#include "../shapes/miscinf.h"
 #include "../shapes/font.h"
 #include "../shapes/fontvga.h"
 #include "../shapes/items.h"
-#include "../shapes/monstinf.h"
-#include "../shapes/shapeinf.h"
 #include "../shapes/shapevga.h"
 #include "../shapes/u7drag.h"
 #include "../shapes/vgafile.h"
