@@ -1,7 +1,7 @@
 /*
- *	npcnear.h - At random times, run proximity usecode functions on nearby NPC's.
+ *  npcnear.h - At random times, run proximity usecode functions on nearby NPC's.
  *
- *  Copyright (C) 2000-2001  The Exult Team
+ *  Copyright (C) 2000-2013  The Exult Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,36 +19,34 @@
  */
 
 #ifndef NPCNEAR_H
-#define	NPCNEAR_H	1
+#define NPCNEAR_H   1
 
-#include "lists.h"
 #include "tqueue.h"
 
 class Game_window;
 class Npc_actor;
+class Actor;
 
 /*
- *	This class keeps track of NPC's nearby, and randomly runs the Usecode
- *	proximity functions for them.
+ *  This class keeps track of NPC's nearby, and randomly runs the Usecode
+ *  proximity functions for them.
  */
-class Npc_proximity_handler : public Time_sensitive
-	{
+class Npc_proximity_handler : public Time_sensitive {
 	Game_window *gwin;
-	unsigned long wait_until;	// Skip running usecodes until past.
+	unsigned long wait_until;   // Skip running usecodes until past.
 public:
-	Npc_proximity_handler(Game_window *gw) : gwin(gw)
-		{
+	Npc_proximity_handler(Game_window *gw) : gwin(gw) {
 		wait_until = 0;
-		}
-					// Add npc to queue.
+	}
+	// Add npc to queue.
 	void add(unsigned long curtime, Npc_actor *npc,
-					int additional_secs = 0);
-	void remove(Npc_actor *npc);	// Remove.
-					// Run usecode function.
-	void handle_event(unsigned long curtime, long udata);
-					// Wait before running more funs.
+	         int additional_secs = 0);
+	void remove(Npc_actor *npc);    // Remove.
+	// Run usecode function.
+	void handle_event(unsigned long curtime, uintptr udata);
+	// Wait before running more funs.
 	void wait(int secs);
-	void get_all(Actor_queue& list);	// Fill list with nearby NPC's.
-	};
+	void get_all(std::vector<Actor *> &list); // Fill list with nearby NPC's.
+};
 
-#endif	/* INCL_NPCNEAR */
+#endif  /* INCL_NPCNEAR */
