@@ -1,7 +1,7 @@
 /*
- *	Npctime.h - Timed-even handlers for NPC's.
+ *  Npctime.h - Timed-even handlers for NPC's.
  *
- *  Copyright (C) 2000-2001  The Exult Team
+ *  Copyright (C) 2000-2013  The Exult Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  */
 
 #ifndef NPCTIME_H
-#define	NPCTIME_H	1
+#define NPCTIME_H   1
 
 #include "tqueue.h"
 
@@ -33,17 +33,16 @@ class Npc_protection_timer;
 class Npc_flag_timer;
 
 /*
- *	List of references to timers for an NPC.
+ *  List of references to timers for an NPC.
  */
-class Npc_timer_list
-	{
+class Npc_timer_list {
 	Actor *npc;
 	Npc_hunger_timer *hunger;
 	Npc_poison_timer *poison;
 	Npc_sleep_timer *sleep;
 	Npc_invisibility_timer *invisibility;
 	Npc_protection_timer *protection;
-	Npc_flag_timer *might, *curse, *paralyze;
+	Npc_flag_timer *might, *curse, *charm, *paralyze;
 public:
 	friend class Npc_hunger_timer;
 	friend class Npc_poison_timer;
@@ -52,9 +51,9 @@ public:
 	friend class Npc_protection_timer;
 	friend class Npc_flag_timer;
 	Npc_timer_list(Actor *n) : npc(n), hunger(0), poison(0), sleep(0),
-			invisibility(0), protection(0), might(0), curse(0),
-			paralyze(0)
-		{  }
+		invisibility(0), protection(0), might(0), curse(0),
+		charm(0), paralyze(0)
+	{  }
 	~Npc_timer_list();
 	void start_hunger();
 	void start_poison();
@@ -63,7 +62,8 @@ public:
 	void start_protection();
 	void start_might();
 	void start_curse();
+	void start_charm();
 	void start_paralyze();
-	};
+};
 
-#endif	/* INCL_NPCTIME */
+#endif  /* INCL_NPCTIME */
