@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2001 The Exult Team
+Copyright (C) 2001-2013 The Exult Team
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,68 +22,59 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "jawbone.h"
 #include "objiter.h"
+#include "exult.h"
+#include "ShortcutBar_gump.h"
+#include "ignore_unused_variable_warning.h"
 
 // Add an object.
-bool Jawbone_object::add(Game_object *obj, bool dont_check, bool combine)
-{
-	if (obj->get_shapenum() != 559)
-		return false; // not a serpent tooth
+bool Jawbone_object::add(
+    Game_object *obj,
+    bool dont_check,        // 1 to skip volume/recursion check.
+    bool combine,           // True to try to combine obj.  MAY
+    //   cause obj to be deleted.
+    bool noset      // True to prevent actors from setting sched. weapon.
+) {
+	ignore_unused_variable_warning(noset);
+	if (!Container_game_object::add(obj, dont_check, combine))
+		return false; // Can't be added to.
 
 	find_teeth();
-	if (teeth[obj->get_framenum()])
-		return false; // already have this one
-
-	if (Container_game_object::add(obj, dont_check)) {
-		
-
-		teeth[obj->get_framenum()] = obj;
-		toothcount++;
-
-		update_frame();
-
-		return true;
-	} 
-
-	return false;
+	update_frame();
+	if(g_shortcutBar)
+		g_shortcutBar->set_changed();
+	return true;
 }
 
 // Remove an object.
-void Jawbone_object::remove(Game_object *obj)
-{
+void Jawbone_object::remove(Game_object *obj) {
 	Container_game_object::remove(obj);
 
 	find_teeth();
 	update_frame();
+	if(g_shortcutBar)
+		g_shortcutBar->set_changed();
 }
 
-void Jawbone_object::find_teeth()
-{
-	for (int i=0; i<19; i++)
+void Jawbone_object::find_teeth() {
+	for (int i = 0; i < 19; i++)
 		teeth[i] = 0;
 	toothcount = 0;
 
-	Object_list& objects = get_objects();
+	Object_list &objects = get_objects();
 	if (objects.is_empty())
-		return;			// Empty.
+		return;         // Empty.
 
 	Game_object *obj;
 	Object_iterator next(objects);
 
 	while ((obj = next.get_next()) != 0)
-	{
-		if (obj->get_shapenum() != 559) {
-//			obj = obj->get_next();
-			continue; // not a serpent tooth... (shouldn't happen)
-		}
-
-		toothcount++;
 		teeth[obj->get_framenum()] = obj;
 
-//		obj = obj->get_next();
-	}
+	for (int i = 0; i < 19; i++)
+		if (teeth[i])
+			toothcount++;
 }
 
-void Jawbone_object::update_frame()
-{
+void Jawbone_object::update_frame() {
 	set_frame(toothcount);
 }
