@@ -1,7 +1,7 @@
 /**
- **	Ordinfo.h - Ordering information.
+ ** Ordinfo.h - Ordering information.
  **
- **	Written: 10/1/98 - JSF
+ ** Written: 10/1/98 - JSF
  **/
 
 /*
@@ -23,53 +23,60 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #ifndef INCL_ORDINFO
-#define INCL_ORDINFO	1
+#define INCL_ORDINFO    1
+
+#include "ignore_unused_variable_warning.h"
+
+#include "objs.h"
+#include "gamewin.h"
+#include "shapeinf.h"
 
 /*
- *	Information about an object used during render-order comparison (lt()):
+ *  Information about an object used during render-order comparison (lt()):
  */
-class Ordering_info
-	{
+class Ordering_info {
 public:
-	Rectangle area;			// Area (pixels) rel. to screen.
-	Shape_info& info;		// Info. about shape.
-	int tx, ty, tz;			// Absolute tile coords.
-	int xs, ys, zs;			// Tile dimensions.
-#if 1	/* For experimental compare(). */
+	Rectangle area;         // Area (pixels) rel. to screen.
+	const Shape_info &info;       // Info. about shape.
+	int tx, ty, tz;         // Absolute tile coords.
+	int xs, ys, zs;         // Tile dimensions.
+#if 1   /* For experimental compare(). */
 	int xleft, xright, ynear, yfar, zbot, ztop;
 #endif
 private:
-	void init(const Game_object *obj)
-		{
+	void init(const Game_object *obj) {
 		Tile_coord t = obj->get_tile();
-		tx = t.tx; ty = t.ty; tz = t.tz;
+		tx = t.tx;
+		ty = t.ty;
+		tz = t.tz;
 		int frnum = obj->get_framenum();
 		xs = info.get_3d_xtiles(frnum);
 		ys = info.get_3d_ytiles(frnum);
 		zs = info.get_3d_height();
-#if 1	/* For experimental compare(). */
+#if 1   /* For experimental compare(). */
 		xleft = tx - xs + 1;
 		xright = tx;
 		yfar = ty - ys + 1;
 		ynear = ty;
 		ztop = tz + zs - 1;
 		zbot = tz;
-		if (!zs)		// Flat?
+		if (!zs)        // Flat?
 			zbot--;
 #endif
-		}
+	}
 public:
-	friend class Game_object;
-	friend class Map_chunk;
-					// Create from scratch.
-	Ordering_info(Game_window *gwin, Game_object *obj)
+	// Create from scratch.
+	Ordering_info(const Game_window *gwin, const Game_object *obj)
 		: area(gwin->get_shape_rect(obj)),
-		  info(obj->get_info())
-		{ init(obj); }
-	Ordering_info(Game_window *gwin, Game_object *obj, Rectangle& a)
+		  info(obj->get_info()) {
+		init(obj);
+	}
+	Ordering_info(const Game_window *gwin, const Game_object *obj, Rectangle &a)
 		: area(a),
-		  info(obj->get_info())
-		{ init(obj); }
-	};
+		  info(obj->get_info()) {
+		ignore_unused_variable_warning(gwin);
+		init(obj);
+	}
+};
 
 #endif
