@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2001  The Exult Team
+ *  Copyright (C) 2000-2013  The Exult Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,22 +24,21 @@
 #include "Astar.h"
 
 /*
- *	Find path from source to destination.
+ *  Find path from source to destination.
  *
- *	Output:	1 if successful, else 0.
+ *  Output: 1 if successful, else 0.
  */
-int Astar::NewPath(Tile_coord s, Tile_coord d, Pathfinder_client *client)
-{
-	extern Tile_coord *Find_path(Tile_coord, Tile_coord,
-					Pathfinder_client *client, int& plen);
-	src = s;			// Store start, destination.
+int Astar::NewPath(Tile_coord const &s, Tile_coord const &d, Pathfinder_client *client) {
+	extern Tile_coord *Find_path(Tile_coord const &, Tile_coord const &,
+	                             Pathfinder_client * client, int & plen);
+	src = s;            // Store start, destination.
 	dest = d;
-	path.clear();		// Clear out old path, if there.
+	path.clear();       // Clear out old path, if there.
 	Tile_coord *t = Find_path(s, d, client, pathlen);
 	bool success = (t != 0);
-	for(int i=0;i<pathlen;i++)
+	for (int i = 0; i < pathlen; i++)
 		path.push_back(t[i]);
-	delete [] t;	// Discard temporary storage
+	delete [] t;    // Discard temporary storage
 	next_index = 0;
 	dir = 1;
 	stop = pathlen;
@@ -47,17 +46,15 @@ int Astar::NewPath(Tile_coord s, Tile_coord d, Pathfinder_client *client)
 }
 
 /*
- *	Get next point on path to go to (in tile coords).
+ *  Get next point on path to go to (in tile coords).
  *
- *	Output:	0 if all done.
+ *  Output: 0 if all done.
  */
-int Astar::GetNextStep(Tile_coord& n, bool& done)
-{
-	if (next_index == stop)
-		{
+int Astar::GetNextStep(Tile_coord &n, bool &done) {
+	if (next_index == stop) {
 		done = true;
 		return (0);
-		}
+	}
 	n = path[next_index];
 	next_index += dir;
 	done = (next_index == stop);
@@ -65,36 +62,30 @@ int Astar::GetNextStep(Tile_coord& n, bool& done)
 }
 
 /*
- *	Set to traverse backwards.
+ *  Set to traverse backwards.
  *
- *	Output:	1 always (we succeeded).
+ *  Output: 1 always (we succeeded).
  */
-int Astar::set_backwards
-	(
-	)
-	{
+int Astar::set_backwards(
+) {
 	dir = -1;
 	stop = -1;
 	next_index = pathlen - 1;
 	return 1;
-	}
+}
 
 /*
- *	Get # steps left.
+ *  Get # steps left.
  */
-int Astar::get_num_steps
-	(
-	)
-	{
-	return (stop - next_index)*dir;
-	}
+int Astar::get_num_steps(
+) {
+	return (stop - next_index) * dir;
+}
 
 /*
- *	Delete.
+ *  Delete.
  */
-Astar::~Astar
-	(
-	)
-	{
-	}
+Astar::~Astar(
+) {
+}
 
