@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2002  The Exult Team
+ *  Copyright (C) 2000-2013  The Exult Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,14 +17,13 @@
  */
 
 #ifndef SINGLES_H
-#define SINGLES_H	1
+#define SINGLES_H   1
 
 /*
- *	'Singletons' used throughout the code.
- *	NOTE:  For now, the implementation is in shapeid.cc.
+ *  'Singletons' used throughout the code.
+ *  NOTE:  For now, the implementation is in shapeid.cc.
  */
-class Game_singletons
-	{
+class Game_singletons {
 protected:
 	static class Game_window *gwin;
 	static class Game_map *gmap;
@@ -35,8 +34,10 @@ protected:
 	static class Palette *pal;
 	static class Gump_manager *gumpman;
 	static class Party_manager *partyman;
+	static class FileSystem *pent_filesys;
+	friend class Game_window;
 public:
 	static void init(Game_window *g);
-	};
+};
 
 #endif
