@@ -1,7 +1,7 @@
 /**
- **	Textpack.cc - Convert text file to a Flex file.
+ ** Textpack.cc - Convert text file to a Flex file.
  **
- **	Written: 2/14/2002
+ ** Written: 2/14/2002
  **/
 
 /*
@@ -26,20 +26,18 @@
 #  include <config.h>
 #endif
 
-#ifndef ALPHA_LINUX_CXX
-#  include <unistd.h>
-#  include <fstream>
-#  include <cstdio>
-#  include <cstdlib>
-#endif
+#include <unistd.h>
+#include <fstream>
+#include <cstdio>
+#include <cstdlib>
 #include <iostream>
+#include <string>
 #include <vector>
 #include "Flex.h"
 #include "utils.h"
 #include "exceptions.h"
 #include "msgfile.h"
 
-using std::atoi;
 using std::cerr;
 using std::cin;
 using std::cout;
@@ -50,169 +48,146 @@ using std::ofstream;
 using std::istream;
 using std::ostream;
 using std::size_t;
-using std::strlen;
+using std::string;
 using std::vector;
 
 /*
- *	Read in a Flex file where each entry is a 0-delimited text string.
+ *  Read in a Flex file where each entry is a 0-delimited text string.
  */
 
-static void Read_flex
-	(
-	const char *filename,		// File to read.
-	vector<char *>& strings		// Strings are stored here.
-	)
-	{
-	Flex in(filename);		// May throw exception.
+static void Read_flex(
+    const char *filename,       // File to read.
+    vector<string> &strings     // Strings are stored here.
+) {
+	FlexFile in(filename);      // May throw exception.
 	int cnt = in.number_of_objects();
 	strings.resize(cnt);
-	for (int i = 0; i < cnt; i++)
-		{
+	for (int i = 0; i < cnt; i++) {
 		size_t len;
-		strings[i] = in.retrieve(i, len);
-		if (!len)		// Empty?
-			{
-			delete strings[i];
-			strings[i] = 0;
-			}
+		const char *ptr = in.retrieve(i, len);
+		if (len) {     // Not empty?
+			strings[i] = ptr;
+			delete [] ptr;
 		}
-	}	
+	}
+}
 
 /*
- *	Write out a Flex file where each entry is a 0-delimited text string.
+ *  Write out a Flex file where each entry is a 0-delimited text string.
  */
 
-static void Write_flex
-	(
-	const char *filename,		// File to write.
-	char *title,			// For the header.
-	vector<char *>& strings		// Okay if some are null.
-	)
-	{
+static void Write_flex(
+    const char *filename,       // File to write.
+    const char *title,          // For the header.
+    vector<string> &strings     // Okay if some are null.
+) {
 	ofstream out;
-	U7open(out, filename);		// May throw exception.
+	U7open(out, filename);      // May throw exception.
 	Flex_writer writer(out, title, strings.size());
-	for (vector<char *>::const_iterator it = strings.begin();
-					it != strings.end(); ++it)
-		{
-		const char *str = *it;
-		if (str)
+	for (vector<string>::const_iterator it = strings.begin();
+	        it != strings.end(); ++it) {
+		const string &str = *it;
+		if (!str.empty())
 			out << str;
-		out.put((char) 0);	// 0-delimit.
+		out.put(0); // 0-delimit.
 		writer.mark_section_done();
-		}
+	}
 	if (!writer.close())
 		throw file_write_exception(filename);
-	}
+}
 
 /*
- *	Write out text, with each line in the form "nnn:sssss", where nnn is
- *	the Flex entry #, and anything after the ':' is the string.
- *	NOTES:	Null entry #'s will be skipped in the output.
- *		Max. text length is 1024.
+ *  Write out text, with each line in the form "nnn:sssss", where nnn is
+ *  the Flex entry #, and anything after the ':' is the string.
+ *  NOTES:  Null entry #'s will be skipped in the output.
+ *      Max. text length is 1024.
  */
 
-static void Write_text
-	(
-	ostream& out,
-	vector<char *>& strings		// Strings to write.
-	)
-	{
+static void Write_text(
+    ostream &out,
+    vector<string> &strings     // Strings to write.
+) {
 	out << "# Written by Exult Textpack tool" << endl;
 	int cnt = strings.size();
-	for (int i = 0; i < cnt; i++)
-		{
-		char *text = strings[i];
-		if (!text)
+	for (int i = 0; i < cnt; i++) {
+		string &text = strings[i];
+		if (text.empty())
 			continue;
-		if (strlen(text) + 1 > 1024)
-			{
+		if (text.size() + 1 > 1024) {
 			cerr << "Text in entry " << i << " is too long"
-							<< endl;
+			     << endl;
 			exit(1);
-			}
-		out << i << ':' << text << endl;
 		}
+		out << i << ':' << text << endl;
+	}
 	out.flush();
-	}
+}
 
 /*
- *	Print usage and exit.
+ *  Print usage and exit.
  */
 
-static void Usage()
-	{
+static void Usage() {
 	cerr << "Usage: textpack -[x|c] flexfile [textfile]" << endl <<
-		"    Missing [textfile] => stdin/stdout" << endl;
+	     "    Missing [textfile] => stdin/stdout" << endl;
 	exit(1);
-	}
+}
 
 /*
- *	Create or extract from Flex files consisting of text entries.
+ *  Create or extract from Flex files consisting of text entries.
  */
 
-int main
-	(
-	int argc,
-	char **argv
-	)
-	{
+int main(
+    int argc,
+    char **argv
+) {
 	if (argc < 3 || argv[1][0] != '-')
-		Usage();		// (Exits.)
+		Usage();        // (Exits.)
 	char *flexname = argv[2];
-	vector<char *> strings;		// Text stored here.
-	switch (argv[1][1])		// Which function?
-		{
-	case 'c':			// Create Flex.
-		if (argc >= 4)		// Text filename given?
-			{
-			ifstream in;	// Open as text.
+	vector<string> strings;     // Text stored here.
+	switch (argv[1][1]) {   // Which function?
+	case 'c':           // Create Flex.
+		if (argc >= 4) {    // Text filename given?
+			ifstream in;    // Open as text.
 			try {
 				U7open(in, argv[3], true);
-			} catch (exult_exception& e) {
+			} catch (exult_exception &e) {
 				cerr << e.what() << endl;
 				exit(1);
 			}
 			if (Read_text_msg_file(in, strings) == -1)
 				exit(1);
-			}
-		else			// Default to stdin.
+		} else          // Default to stdin.
 			if (Read_text_msg_file(cin, strings) == -1)
 				exit(1);
 		try {
 			Write_flex(flexname, "Flex created by Exult", strings);
-		} catch (exult_exception& e){
+		} catch (exult_exception &e) {
 			cerr << e.what() << endl;
 			exit(1);
 		}
 		break;
-	case 'x':			// Extract to text.
+	case 'x':           // Extract to text.
 		try {
 			Read_flex(flexname, strings);
-		} catch (exult_exception& e){
+		} catch (exult_exception &e) {
 			cerr << e.what() << endl;
 			exit(1);
 		}
-		if (argc >= 4)		// Text file given?
-			{
+		if (argc >= 4) {    // Text file given?
 			ofstream out;
 			try {
 				U7open(out, argv[3],  true);
-			} catch(exult_exception& e) {
+			} catch (exult_exception &e) {
 				cerr << e.what() << endl;
 				exit(1);
 			}
 			Write_text(out, strings);
-			}
-		else
+		} else
 			Write_text(cout, strings);
 		break;
 	default:
 		Usage();
-		}
-					// Clean up allocated strings.
-	for (vector<char *>::iterator it = strings.begin(); 
-						it != strings.end(); ++it)
-		delete *it;
-	return 0;
 	}
+	return 0;
+}
