@@ -1,7 +1,7 @@
 /**
- **	Ucmain.cc - Usecode Compiler
+ ** Ucmain.cc - Usecode Compiler
  **
- **	Written: 12/30/2000 - JSF
+ ** Written: 12/30/2000 - JSF
  **/
 
 /*
@@ -30,82 +30,78 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <unistd.h>
 #include <stdio.h>
 #include <string>
+#include <cstring>
+#include <cstdlib>
 #include <vector>
 #include "ucloc.h"
 #include "ucfun.h"
+#include "ucsymtbl.h"
+#include "utils.h"
 
-#ifndef ALPHA_LINUX_CXX
-#  include <iosfwd>
-#endif
+#include <iosfwd>
 
 using std::strcpy;
 using std::strrchr;
 using std::strlen;
 using std::ios;
 
-					// THIS is what the parser produces.
-extern std::vector<Uc_function *> functions;	
+// THIS is what the parser produces.
+extern std::vector<Uc_design_unit *> units;
 
-std::vector<char *> include_dirs;	// -I directories.
+std::vector<char *> include_dirs;   // -I directories.
 
 /*
- *	MAIN.
+ *  MAIN.
  */
 
-int main
-	(
-	int argc,
-	char **argv
-	)
-	{
+int main(
+    int argc,
+    char **argv
+) {
 	extern int yyparse();
 	extern FILE *yyin;
-	char *src;
+	const char *src;
 	char outbuf[256];
 	char *outname = 0;
-	static char *optstring = "o:I:s";
-	extern int optind, opterr, optopt;
-	extern char *optarg;
-	Uc_function::Intrinsic_type ty = Uc_function::bg;
-	opterr = 0;			// Don't let getopt() print errs.
+	static const char *optstring = "o:I:s";
+	Uc_function::Intrinsic_type ty = Uc_function::unset;
+	opterr = 0;         // Don't let getopt() print errs.
 	int optchr;
 	while ((optchr = getopt(argc, argv, optstring)) != -1)
-		switch (optchr)
-			{
-		case 'o':		// Output to write.
+		switch (optchr) {
+		case 'o':       // Output to write.
 			outname = optarg;
 			break;
-		case 'I':		// Include dir.
+		case 'I':       // Include dir.
 			include_dirs.push_back(optarg);
 			break;
 		case 's':
 			ty = Uc_function::si;
 			break;
-			}
-	if (optind < argc)		// Filename?
-		{
+		}
+	char *env = getenv("UCC_INCLUDE");
+	if (env)
+		include_dirs.push_back(env);
+	if (optind < argc) {    // Filename?
 		src = argv[optind];
 		yyin = fopen(argv[optind], "r");
-		if (!outname)		// No -o option?
-			{		// Set up output name.
+		if (!outname) {     // No -o option?
+			// Set up output name.
 			outname = strncpy(outbuf, src, sizeof(outbuf) - 5);
 			outbuf[sizeof(outbuf) - 5] = 0;
 			char *dot = strrchr(outname, '.');
 			if (!dot)
 				dot = outname + strlen(outname);
 			strcpy(dot, ".uco");
-			}
 		}
-	else
-		{
+	} else {
 		src = "<stdin>";
 		yyin = stdin;
 		if (!outname)
 			outname = strcpy(outbuf, "a.ucout");
-		}
+	}
 	Uc_location::set_cur(src, 0);
-					// For now, use black gate.
-	Uc_function::set_intrinsics(ty);
+	Uc_function::set_intrinsic_type(ty);
 #if 0
 //++++TESTING
 	int tok;
@@ -114,27 +110,45 @@ int main
 		printf("%d\n", tok);
 #endif
 	yyparse();
+	if (yyin != stdin) fclose(yyin);
 	int errs = Uc_location::get_num_errors();
-	if (errs > 0)			// Check for errors.
+	if (errs > 0)           // Check for errors.
 		return errs;
-					// Open output.
-	std::ofstream out(outname, ios::binary|ios::out);
-	for (std::vector<Uc_function *>::iterator it = functions.begin();
-					it != functions.end(); it++)
-		{
-		Uc_function *fun = *it;
-		fun->gen(out);		// Generate function.
-		}
-	return Uc_location::get_num_errors();
+	// Open output.
+	std::ofstream out(outname, ios::binary | ios::out);
+	if (!out.good()) {
+		std::cout << "Could not open output file '" << outname << "'!" << std::endl;
+		return 1;
 	}
+	Write4(out, UCSYMTBL_MAGIC0);   // Start with symbol table.
+	Write4(out, UCSYMTBL_MAGIC1);
+	std::vector<Uc_design_unit *>::iterator it;
+	Usecode_symbol_table *symtbl = new Usecode_symbol_table;
+	for (it = units.begin(); it != units.end(); ++it) {
+		symtbl->add_sym((*it)->create_sym());
+	}
+	symtbl->write(out);
+	delete symtbl;
+	for (it = units.begin(); it != units.end(); ++it) {
+		(*it)->gen(out);    // Generate function.
+	}
+	return Uc_location::get_num_errors();
+}
 
 /*
- *	Report error.
+ *  Report error.
  */
-void yyerror
-	(
-	char *s
-	)
-	{
+void yyerror(
+    const char *s
+) {
 	Uc_location::yyerror(s);
-	}
+}
+
+/*
+ *  Report warning.
+ */
+void yywarning(
+    const char *s
+) {
+	Uc_location::yywarning(s);
+}
