@@ -1,5 +1,5 @@
 /*
- *	ucfunction.cc - Usecode function
+ *  ucfunction.cc - Usecode function
  *
  *  Copyright (C) 2002  The Exult Team
  *
@@ -29,18 +29,21 @@ using std::istream;
 #include "utils.h"
 
 /*
- *	Read in a function.
+ *  Read in a function.
  */
 
-Usecode_function::Usecode_function
-	(
-	istream& file
-	) : orig(0)
-{
+Usecode_function::Usecode_function(
+    istream &file
+) : orig(0) {
 	id = Read2(file);
 
-	// support for our extended usecode format. (32 bit lengths)
-	if (id == 0xFFFF) {
+	// support for our extended usecode format. (32 bit lengths and ids)
+	if (id == 0xfffe) {
+		id = Read4s(file);
+		len = Read4(file);
+		extended = true;
+		// older extended usecode format. (32 bit lengths)
+	} else if (id == 0xffff) {
 		id = Read2(file);
 		len = Read4(file);
 		extended = true;
@@ -49,7 +52,7 @@ Usecode_function::Usecode_function
 		extended = false;
 	}
 
-	code = new unsigned char[len];	// Allocate buffer & read it in.
-	file.read((char*)code, len);
+	code = new unsigned char[len];  // Allocate buffer & read it in.
+	file.read(reinterpret_cast<char *>(code), len);
 }
 
