@@ -1,8 +1,8 @@
 /*
- *	ucmachine.cc - Interpreter for usecode.
+ *  ucmachine.cc - Interpreter for usecode.
  *
  *  Copyright (C) 1999  Jeffrey S. Freedman
- *  Copyright (C) 2000-2001  The Exult Team
+ *  Copyright (C) 2000-2013  The Exult Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,40 +23,35 @@
 #  include <config.h>
 #endif
 
+#include <cstring>
 #include "ucmachine.h"
 #include "keyring.h"
 #include "conversation.h"
 
 
-Usecode_machine::Usecode_machine
-	(
-	) : keyring(0), conv(0)
-	{
-					// Clear global flags.
+Usecode_machine::Usecode_machine(
+) : keyring(0), conv(0) {
+	// Clear global flags.
 	std::memset(gflags, 0, sizeof(gflags));
 	conv = new Conversation;
 	keyring = new Keyring;
-	}
+}
 
 /*
- *	Delete.
+ *  Delete.
  */
 
-Usecode_machine::~Usecode_machine
-	(
-	)
-	{
+Usecode_machine::~Usecode_machine(
+) {
 	delete conv;
 	delete keyring;
-	}
+}
 
-void Usecode_machine::init_conversation()
-{
+void Usecode_machine::init_conversation() {
 	conv->init_faces();
 }
 
-int Usecode_machine::get_num_faces_on_screen() const
-{
-	 return conv->get_num_faces_on_screen();
+int Usecode_machine::get_num_faces_on_screen() const {
+	return conv->get_num_faces_on_screen();
 }
 
