@@ -1,5 +1,5 @@
 /*
- *	ucserial.h - Serialization of usecode objects
+ *  ucserial.h - Serialization of usecode objects
  *
  *  Copyright (C) 2002  The Exult Team
  *
@@ -25,33 +25,31 @@
 
 class Usecode_value;
 
-extern int Stack_frame_out
-	(
-	int fd,				// Socket.
-	int functionid,
-	int ip,
-	int call_chain,
-	int call_depth,
-	int eventid,
-	int caller_item,
-	int num_args,
-	int num_vars,
-	Usecode_value* locals
-	);
-extern bool Stack_frame_in
-	(
-	unsigned char *data,		// Data that was read.
-	int datalen,			// Length of data.
-	int& functionid,
-	int& ip,
-	int& call_chain,
-	int& call_depth,
-	int& eventid,
-	int& caller_item,
-	int& num_args,
-	int& num_vars,
-	Usecode_value*& locals
-	);
+extern int Stack_frame_out(
+    int fd,             // Socket.
+    int functionid,
+    int ip,
+    int call_chain,
+    int call_depth,
+    int eventid,
+    int caller_item,
+    int num_args,
+    int num_vars,
+    Usecode_value *locals
+);
+extern bool Stack_frame_in(
+    const unsigned char *data,        // Data that was read.
+    int datalen,            // Length of data.
+    int &functionid,
+    int &ip,
+    int &call_chain,
+    int &call_depth,
+    int &eventid,
+    int &caller_item,
+    int &num_args,
+    int &num_vars,
+    Usecode_value *&locals
+);
 
 
 #endif
